function [plotInfo] = tlNextPlot(plotInfo_in, option)
%TL_NEXTPLOT Summary of this function goes here
%   Detailed explanation goes here

    if ~exist('option', 'var')
        option = 'next';
    end

    plotInfo = plotInfo_in;

    % go to the next plot location
    if isnumeric(option)
        % span multiple plots
        loSubPlotIdx = plotInfo.curPlotIdx + 1;
        plotInfo.curPlotIdx = plotInfo.curPlotIdx + option;  
    else
        switch option
            case 'row'
                plotInfo.curPlotIdx = plotInfo.curPlotIdx + ...
                    (plotInfo.figureSize(2) - mod(plotInfo.curPlotIdx - 1, plotInfo.figureSize(2)));
            case 'figure'
                plotInfo.curPlotIdx = plotInfo.curPlotIdx + ...
                    (plotInfo.numPlotsPerFigure - mod(plotInfo.curPlotIdx - 1, plotInfo.numPlotsPerFigure));
            otherwise
                plotInfo.curPlotIdx = plotInfo.curPlotIdx + 1;        
        end
    end
    
    % find the subplot index
    subplotIdx = mod(plotInfo.curPlotIdx - 1, plotInfo.numPlotsPerFigure) + 1;    
    if exist('loSubPlotIdx', 'var')
        subplotIdx = (mod(loSubPlotIdx - 1, plotInfo.numPlotsPerFigure) + 1):subplotIdx;
    end
    
    % focus the figure
    if subplotIdx(1) == 1
        if plotInfo.curPlotIdx == 1
            % very first subplot
            plotInfo.curFigureIdx = plotInfo.curFigureIdx + 1;
            plotInfo.usedFigureIds = [plotInfo.usedFigureIds plotInfo.curFigureIdx];
        else
            % next figure
            if strcmp(plotInfo.nextFigureType, 'pause')
                pause;
            else            
                plotInfo.curFigureIdx = plotInfo.curFigureIdx + 1;
                plotInfo.usedFigureIds = [plotInfo.usedFigureIds plotInfo.curFigureIdx];
            end
        end
        sfigure(plotInfo.curFigureIdx);
        clf;
    else
        sfigure(plotInfo.curFigureIdx);
    end
    
    % focus the subplot
    subplot(plotInfo.figureSize(1), plotInfo.figureSize(2), subplotIdx);
    hold on;

end

function h = sfigure(h)
% SFIGURE  Create figure window (minus annoying focus-theft).
%
% Usage is identical to figure.
%
% Daniel Eaton, 2005
%
% See also figure

if nargin>=1 
	if ishandle(h)
		set(0, 'CurrentFigure', h);
	else
		h = figure(h);
	end
else
	h = figure;
end

end

