function pr = postprocessOneImage(idIm,params,params_postprocess)

im = imread(sprintf('data/%s/%s.jpg',idIm,idIm));
sz = size(im);


% Load ground truth bw
% --------------------
load(sprintf('data/%s/%s-pos.mat', idIm,idIm),'imRegions');
gt.BW = imRegions;
clear imRegions;
nGt = size(gt.BW,3);


% Load detection bw
% -----------------
load(sprintf('detect/%s/%s_%s.mat',idIm,idIm,params.grouping.string),'parts');
dets.BW = cat(3,parts.imRegions);
if isfield(parts,'regionAlpha')
    dets.scores = cat(1,parts.regionAlpha)';
else
    dets.scores = cat(1,parts.scores);
end
clear parts;

nDet = size(dets.BW,3);



if params_postprocess.doNMS
    mSuppress = false(nDet,1);
    [~,Idescend] = sort(dets.scores,'descend');    
    for i=1:min(60,nDet)
    for j=1:(i-1)
        BWi = dets.BW(:,:,Idescend(i));
        BWj = dets.BW(:,:,Idescend(j));
        int = BWi & BWj;
        un = BWi | BWj;
        IoU = sum(int(:))/sum(un(:));
        if IoU > .7
            mSuppress(Idescend(i))=1;
            break;
        end
    end
    end
    fprintf('NMS -- suppress %d\n',sum(mSuppress));
    dets.BW = dets.BW(:,:,~mSuppress);
    dets.scores = dets.scores(~mSuppress);
    nDet = size(dets.BW,3);
end





% Compute IoU matrix and thresholded version
% ------------------------------------------
matIoU = zeros(nGt,nDet);
for i=1:nGt
for j=1:nDet
    int = gt.BW(:,:,i) & dets.BW(:,:,j);
    un = gt.BW(:,:,i) | dets.BW(:,:,j);        
    IoU = sum(int(:))/sum(un(:));
    matIoU(i,j) = IoU;
end
end
matIoUthres = matIoU > params_postprocess.IoUmin;



% Compute 1-1 correspondence matrix
% ---------------------------------
matHits = matIoUthres;

% assign to each det the best overlapping gt, if any
for i=1:nDet
    o = -inf(nGt,1);
    o(matIoUthres(:,i)) = matIoU(matIoUthres(:,i),i);
    [~,iGtMax] = max(o);
    matHits([1:iGtMax-1 iGtMax+1:end],i)=0;
end

% assign to each gt the best scoring det, if any
for i=1:nGt
    s = -inf(1,nDet);
    s(matHits(i,:)) = dets.scores(matHits(i,:));
    [~,iDetMax] = max(s);
    matHits(i,[1:iDetMax-1 iDetMax+1:end])=0;
end








% Condense hit info for precision-recall
% --------------------------------------
pr.numTruths = nGt;
pr.hits = any(matHits,1);
pr.scores = dets.scores';

% extras:
[Igt,Idet]=find(matHits);
pr.iGt = zeros(nDet,1);
pr.iGt(Idet) = Igt;

pr.iou = zeros(nDet,1);
pr.iou(Idet) = matIoU(sub2ind(size(matIoU),Igt,Idet));

pr.str = cell(nDet,1);
for i=1:nDet
    suf = pr.iGt(i);
    pr.str{i} = sprintf('%s-det%04d-gt%03d',idIm,i,suf);
end











% Save matrices (hits)
% --------------------
idHits = sprintf('postprocess/%s/%s_hits__%s.mat',idIm,idIm,params.grouping.string);
save(idHits,'matIoU','matIoUthres','matHits');

% Save hit visualization
% ----------------------
colours = jet(nGt);
imVis = zeros(sz(1:2));
for i=1:nGt
    imVis = tlMaskOnIm(imVis, gt.BW(:,:,i), colours(i,:));
end
idVis = sprintf('postprocess/%s/%s_gt.png',idIm,idIm);
imwrite(imVis,idVis);

imVis = im;
for i=1:nGt
    iDet = find(matHits(i,:));
    if ~isempty(iDet)
        imVis = tlMaskOnIm(im2double(imVis), dets.BW(:,:,iDet), colours(i,:), 0.7);
    end
end
idHits = sprintf('postprocess/%s/%s_hits__%s.png',idIm,idIm,params.grouping.string);
imwrite(imVis,idHits);









end

